@@ -5,12 +5,14 @@
 
 from os import path
 
+from ecs_composex.common import NONALPHANUM
 from ecs_composex.common.cfn_params import Parameter
 from ecs_composex.common.ecs_composex import X_KEY
 
 MOD_KEY = path.basename(path.dirname(path.abspath(__file__)))
 RES_KEY = f"{X_KEY}{MOD_KEY}"
 SQS_SSM_PREFIX = f"/{RES_KEY}/"
+MAPPINGS_KEY = NONALPHANUM.sub("", MOD_KEY)
 
 SQS_URL_T = "Url"
 SQS_URL = Parameter(SQS_URL_T, Type="String")
